Crate flat_db

Crate flat_db 

Flat file database with chunked storage.

Chunking achieves a balance between minimizing the number of file operations and the performance cost of serializing large numbers of items to a flat file format that can be manually edited and version controlled.

Structs

FileTable
File storage table with chunked directories.
Hash
Fixed-size byte array hash.
Table
Key-value table with chunked file storage.

Enums

FileTableAction
Action being performed when a Failure<FileTableAction> occurred.
HashError
Errors when parsing a Hash from a hexadecimal string.
TableAction
Action being performed when a Failure<TableAction> occurred.