Flat file database with chunked storage.
Chunking achieves a balance between minimizing the number of file operations and the performance cost of serializing large numbers of items to a flat file format that can be manually edited and version controlled.
Structs
- File
Table - File storage table with chunked directories.
- Hash
- Fixed-size byte array hash.
- Table
- Key-value table with chunked file storage.
Enums
- File
Table Action - Action being performed when a
Failure<FileTableAction>occurred. - Hash
Error - Errors when parsing a
Hashfrom a hexadecimal string. - Table
Action - Action being performed when a
Failure<TableAction>occurred.